/**
 * 
 */
package svn.checkout.test;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IResourceChangeEvent;
import org.eclipse.core.resources.IResourceChangeListener;
import org.eclipse.core.resources.IResourceDelta;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.resources.WorkspaceJob;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;

/**
 * @author gdtaylor
 *
 */
public class InitJob extends WorkspaceJob implements IResourceChangeListener{

	/**
	 * @param name
	 */
	public InitJob(String name) {
		super(name);
	}
	
	public void resourceChanged(IResourceChangeEvent event) {
		try
		{
			IResourceDelta delta = event.getDelta();
			if (delta != null)
			{
				IResourceDelta[] projects = delta.getAffectedChildren();
				for (int projectIndex = 0; projectIndex < projects.length; projectIndex++)
				{
					IResourceDelta projectDelta = projects[projectIndex];
					IProject project = projects[projectIndex].getResource().getProject();
					if (project.isAccessible())
					{
						int type = projectDelta.getResource().getType();
						if (type == IResource.PROJECT)
						{
							int kind = projectDelta.getKind();
							int flags = projectDelta.getFlags();
							if ((kind & IResourceDelta.ADDED) == IResourceDelta.ADDED)
							{
								runMigrationJob(project);
							}
							else if ((kind & IResourceDelta.CHANGED) == IResourceDelta.CHANGED)
							{
								if (((flags & IResourceDelta.OPEN) == IResourceDelta.OPEN) || ((flags & IResourceDelta.REPLACED) == IResourceDelta.REPLACED))
								{
									runMigrationJob(project);
								}
							}
						}
					}
				}
			}
		} catch (Exception t) {
			t.printStackTrace();
			throw new RuntimeException(t);
		}
	}

	/* (non-Javadoc)
	 * @see org.eclipse.core.resources.WorkspaceJob#runInWorkspace(org.eclipse.core.runtime.IProgressMonitor)
	 */
	public IStatus runInWorkspace(IProgressMonitor monitor)
			throws CoreException {
		ResourcesPlugin.getWorkspace().addResourceChangeListener(this);
		return Status.OK_STATUS;
	}
	
	protected void runMigrationJob(final IProject project)
	{
		Job job = new Job("svn checkout test job")
		{
			protected IStatus run(IProgressMonitor monitor)
			{
				Utils.projectMarkedAsMigrated(project);
				return Status.OK_STATUS;
			}
		};
		job.setSystem(true);
		job.setRule(ResourcesPlugin.getWorkspace().getRoot());
		job.schedule();	
	}

}
